<?php

declare(strict_types=1);

namespace NOUT\Soap\ServiceType;

use NOUT\Entity\UsernameToken\UsernameTokenInterface;
use SoapFault;
use NOUT\Soap\PackageBase\AbstractSoapClientBase;

/**
 * This class stands for all operations
 * @subpackage Services
 */
class Service extends AbstractSoapClientBase
{
    /**
     * Sets the APIUUID SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param string $aPIUUID
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderAPIUUID(string $aPIUUID, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: string
        if (!is_null($aPIUUID) && !is_string($aPIUUID)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($aPIUUID, true), gettype($aPIUUID)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'APIUUID', $aPIUUID, $mustUnderstand, $actor);
    }
    /**
     * Sets the CustomerInfos SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param string $customerInfos
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderCustomerInfos(string $customerInfos, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: string
        if (!is_null($customerInfos) && !is_string($customerInfos)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($customerInfos, true), gettype($customerInfos)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'CustomerInfos', $customerInfos, $mustUnderstand, $actor);
    }
    /**
     * Sets the OptionDialogue SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param \NOUT\Soap\StructType\OptionDialogue $optionDialogue
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderOptionDialogue(\NOUT\Soap\StructType\OptionDialogue $optionDialogue, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        return $this->setSoapHeader($namespace, 'OptionDialogue', $optionDialogue, $mustUnderstand, $actor);
    }
    /**
     * Sets the APIUser SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param int $aPIUser
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderAPIUser(int $aPIUser, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: int
        if (!is_null($aPIUser) && !(is_int($aPIUser) || ctype_digit($aPIUser))) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($aPIUser, true), gettype($aPIUser)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'APIUser', $aPIUser, $mustUnderstand, $actor);
    }
    /**
     * Sets the SessionToken SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param string $sessionToken
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderSessionToken(string $sessionToken, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: string
        if (!is_null($sessionToken) && !is_string($sessionToken)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($sessionToken, true), gettype($sessionToken)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'SessionToken', $sessionToken, $mustUnderstand, $actor);
    }
    /**
     * Sets the UsernameToken SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param UsernameTokenInterface $usernameToken
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderUsernameToken(UsernameTokenInterface $usernameToken, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        return $this->setSoapHeader($namespace, 'UsernameToken', $usernameToken, $mustUnderstand, $actor);
    }
    /**
     * Sets the ActionContext SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param string $actionContext
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderActionContext(string $actionContext, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: string
        if (!is_null($actionContext) && !is_string($actionContext)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($actionContext, true), gettype($actionContext)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'ActionContext', $actionContext, $mustUnderstand, $actor);
    }
    /**
     * Sets the AutoValidate SoapHeader param
     * @uses AbstractSoapClientBase::setSoapHeader()
     * @param int $autoValidate
     * @param string $namespace
     * @param bool $mustUnderstand
     * @param string|null $actor
     * @return \NOUT\Soap\ServiceType\Service
     */
    public function setSoapHeaderAutoValidate(int $autoValidate, string $namespace = 'http://www.nout.fr/wsdl/SimaxService.wsdl/', bool $mustUnderstand = false, ?string $actor = null): self
    {
        // validation for constraint: int
        if (!is_null($autoValidate) && !(is_int($autoValidate) || ctype_digit($autoValidate))) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($autoValidate, true), gettype($autoValidate)), __LINE__);
        }
        return $this->setSoapHeader($namespace, 'AutoValidate', $autoValidate, $mustUnderstand, $actor);
    }
    /**
     * Method to call the operation originally named Disconnect
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $disconnect
     * @return \NOUT\Soap\StructType\DisconnectResponse|bool
     */
    public function Disconnect(\NOUT\Soap\StructType\EmptyType $disconnect)
    {
        try {
            $this->setResult($resultDisconnect = $this->getSoapClient()->__soapCall('Disconnect', [
                $disconnect,
            ], [], [], $this->outputHeaders));
        
            return $resultDisconnect;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetTokenSession
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue
     * - SOAPHeaders: optional, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetTokenSession $parameters
     * @return \NOUT\Soap\StructType\GetTokenSessionResponse|bool
     */
    public function GetTokenSession(\NOUT\Soap\StructType\GetTokenSession $parameters)
    {
        try {
            $resultGetTokenSession = $this->getSoapClient()->__soapCall('GetTokenSession', [
                $parameters,
            ], [], [], $this->outputHeaders);

            $this->setResult($resultGetTokenSession);
        
            return $resultGetTokenSession;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named InitRecordFromAddress
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\InitRecordFromAddress $parameters
     * @return \NOUT\Soap\StructType\InitRecordFromAddressResponse|bool
     */
    public function InitRecordFromAddress(\NOUT\Soap\StructType\InitRecordFromAddress $parameters)
    {
        try {
            $this->setResult($resultInitRecordFromAddress = $this->getSoapClient()->__soapCall('InitRecordFromAddress', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultInitRecordFromAddress;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named InitRecordFromMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\InitRecordFromMessage $parameters
     * @return \NOUT\Soap\StructType\InitRecordFromMessageResponse|bool
     */
    public function InitRecordFromMessage(\NOUT\Soap\StructType\InitRecordFromMessage $parameters)
    {
        try {
            $this->setResult($resultInitRecordFromMessage = $this->getSoapClient()->__soapCall('InitRecordFromMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultInitRecordFromMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ResetPasswordFailed
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue
     * - SOAPHeaders: optional, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ResetPasswordFailed $parameters
     * @return \NOUT\Soap\StructType\ResetPasswordFailedResponse|bool
     */
    public function ResetPasswordFailed(\NOUT\Soap\StructType\ResetPasswordFailed $parameters)
    {
        try {
            $this->setResult($resultResetPasswordFailed = $this->getSoapClient()->__soapCall('ResetPasswordFailed', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultResetPasswordFailed;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ActionFromMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ActionFromMessage $parameters
     * @return \NOUT\Soap\StructType\ActionFromMessageResponse|bool
     */
    public function ActionFromMessage(\NOUT\Soap\StructType\ActionFromMessage $parameters)
    {
        try {
            $this->setResult($resultActionFromMessage = $this->getSoapClient()->__soapCall('ActionFromMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultActionFromMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named AuditAction
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\AuditAction $parameters
     * @return \NOUT\Soap\StructType\AuditActionResponse|bool
     */
    public function AuditAction(\NOUT\Soap\StructType\AuditAction $parameters)
    {
        try {
            $this->setResult($resultAuditAction = $this->getSoapClient()->__soapCall('AuditAction', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultAuditAction;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named AutoComplete
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\AutoComplete $parameters
     * @return \NOUT\Soap\StructType\AutoCompleteResponse|bool
     */
    public function AutoComplete(\NOUT\Soap\StructType\AutoComplete $parameters)
    {
        try {
            $this->setResult($resultAutoComplete = $this->getSoapClient()->__soapCall('AutoComplete', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultAutoComplete;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ButtonAction
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ButtonAction $parameters
     * @return \NOUT\Soap\StructType\ButtonActionResponse|bool
     */
    public function ButtonAction(\NOUT\Soap\StructType\ButtonAction $parameters)
    {
        try {
            $this->setResult($resultButtonAction = $this->getSoapClient()->__soapCall('ButtonAction', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultButtonAction;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Cancel
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Cancel $parameters
     * @return \NOUT\Soap\StructType\CancelResponse|bool
     */
    public function Cancel(\NOUT\Soap\StructType\Cancel $parameters)
    {
        try {
            $this->setResult($resultCancel = $this->getSoapClient()->__soapCall('Cancel', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCancel;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CheckCtrl
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CheckCtrl $parameters
     * @return \NOUT\Soap\StructType\CheckCtrlResponse|bool
     */
    public function CheckCtrl(\NOUT\Soap\StructType\CheckCtrl $parameters)
    {
        try {
            $this->setResult($resultCheckCtrl = $this->getSoapClient()->__soapCall('CheckCtrl', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCheckCtrl;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ConfirmResponse
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ConfirmResponse $parameters
     * @return \NOUT\Soap\StructType\ConfirmResponseResponse|bool
     */
    public function ConfirmResponse(\NOUT\Soap\StructType\ConfirmResponse $parameters)
    {
        try {
            $this->setResult($resultConfirmResponse = $this->getSoapClient()->__soapCall('ConfirmResponse', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultConfirmResponse;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Copy
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Copy $parameters
     * @return \NOUT\Soap\StructType\CopyResponse|bool
     */
    public function Copy(\NOUT\Soap\StructType\Copy $parameters)
    {
        try {
            $this->setResult($resultCopy = $this->getSoapClient()->__soapCall('Copy', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCopy;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Create
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Create $parameters
     * @return \NOUT\Soap\StructType\CreateResponse|bool
     */
    public function Create(\NOUT\Soap\StructType\Create $parameters)
    {
        try {
            $this->setResult($resultCreate = $this->getSoapClient()->__soapCall('Create', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCreate;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CreateFrom
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CreateFrom $parameters
     * @return \NOUT\Soap\StructType\CreateFromResponse|bool
     */
    public function CreateFrom(\NOUT\Soap\StructType\CreateFrom $parameters)
    {
        try {
            $this->setResult($resultCreateFrom = $this->getSoapClient()->__soapCall('CreateFrom', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCreateFrom;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Delete
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Delete $parameters
     * @return \NOUT\Soap\StructType\DeleteResponse|bool
     */
    public function Delete(\NOUT\Soap\StructType\Delete $parameters)
    {
        try {
            $this->setResult($resultDelete = $this->getSoapClient()->__soapCall('Delete', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDelete;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Display
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Display $parameters
     * @return \NOUT\Soap\StructType\DisplayResponse|bool
     */
    public function Display(\NOUT\Soap\StructType\Display $parameters)
    {
        try {
            $this->setResult($resultDisplay = $this->getSoapClient()->__soapCall('Display', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDisplay;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DrillThrough
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DrillThrough $parameters
     * @return \NOUT\Soap\StructType\DrillThroughResponse|bool
     */
    public function DrillThrough(\NOUT\Soap\StructType\DrillThrough $parameters)
    {
        try {
            $this->setResult($resultDrillThrough = $this->getSoapClient()->__soapCall('DrillThrough', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDrillThrough;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named EnterReorderListMode
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $enterReorderListMode
     * @return \NOUT\Soap\StructType\EnterReorderListModeResponse|bool
     */
    public function EnterReorderListMode(\NOUT\Soap\StructType\EmptyType $enterReorderListMode)
    {
        try {
            $this->setResult($resultEnterReorderListMode = $this->getSoapClient()->__soapCall('EnterReorderListMode', [
                $enterReorderListMode,
            ], [], [], $this->outputHeaders));
        
            return $resultEnterReorderListMode;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Execute
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Execute $parameters
     * @return \NOUT\Soap\StructType\ExecuteResponse|bool
     */
    public function Execute(\NOUT\Soap\StructType\Execute $parameters)
    {
        try {
            $this->setResult($resultExecute = $this->getSoapClient()->__soapCall('Execute', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultExecute;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ExecuteWithoutIHM
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ExecuteWithoutIHM $parameters
     * @return \NOUT\Soap\StructType\ExecuteWithoutIHMResponse|bool
     */
    public function ExecuteWithoutIHM(\NOUT\Soap\StructType\ExecuteWithoutIHM $parameters)
    {
        try {
            $this->setResult($resultExecuteWithoutIHM = $this->getSoapClient()->__soapCall('ExecuteWithoutIHM', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultExecuteWithoutIHM;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Export
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Export $parameters
     * @return \NOUT\Soap\StructType\ExportResponse|bool
     */
    public function Export(\NOUT\Soap\StructType\Export $parameters)
    {
        try {
            $this->setResult($resultExport = $this->getSoapClient()->__soapCall('Export', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultExport;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetCalculation
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetCalculation $parameters
     * @return \NOUT\Soap\StructType\GetCalculationResponse|bool
     */
    public function GetCalculation(\NOUT\Soap\StructType\GetCalculation $parameters)
    {
        try {
            $this->setResult($resultGetCalculation = $this->getSoapClient()->__soapCall('GetCalculation', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetCalculation;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetChart
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetChart $parameters
     * @return \NOUT\Soap\StructType\GetChartResponse|bool
     */
    public function GetChart(\NOUT\Soap\StructType\GetChart $parameters)
    {
        try {
            $this->setResult($resultGetChart = $this->getSoapClient()->__soapCall('GetChart', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetChart;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetColInRecord
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetColInRecord $parameters
     * @return \NOUT\Soap\StructType\GetColInRecordResponse|bool
     */
    public function GetColInRecord(\NOUT\Soap\StructType\GetColInRecord $parameters)
    {
        try {
            $this->setResult($resultGetColInRecord = $this->getSoapClient()->__soapCall('GetColInRecord', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetColInRecord;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetEndAutomatism
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetEndAutomatism $parameters
     * @return \NOUT\Soap\StructType\GetEndAutomatismResponse|bool
     */
    public function GetEndAutomatism(\NOUT\Soap\StructType\GetEndAutomatism $parameters)
    {
        try {
            $this->setResult($resultGetEndAutomatism = $this->getSoapClient()->__soapCall('GetEndAutomatism', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetEndAutomatism;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetEndListCalculation
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $getEndListCalculation
     * @return \NOUT\Soap\StructType\GetEndListCalculationResponse|bool
     */
    public function GetEndListCalculation(\NOUT\Soap\StructType\EmptyType $getEndListCalculation)
    {
        try {
            $this->setResult($resultGetEndListCalculation = $this->getSoapClient()->__soapCall('GetEndListCalculation', [
                $getEndListCalculation,
            ], [], [], $this->outputHeaders));
        
            return $resultGetEndListCalculation;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetLanguages
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue
     * - SOAPHeaders: optional, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $getLanguages
     * @return \NOUT\Soap\StructType\GetLanguagesResponse|bool
     */
    public function GetLanguages(\NOUT\Soap\StructType\EmptyType$getLanguages)
    {
        try {
            $this->setResult($resultGetLanguages = $this->getSoapClient()->__soapCall('GetLanguages', [
                $getLanguages,
            ], [], [], $this->outputHeaders));
        
            return $resultGetLanguages;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetPlanningInfo
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetPlanningInfo $parameters
     * @return \NOUT\Soap\StructType\GetPlanningInfoResponse|bool
     */
    public function GetPlanningInfo(\NOUT\Soap\StructType\GetPlanningInfo $parameters)
    {
        try {
            $this->setResult($resultGetPlanningInfo = $this->getSoapClient()->__soapCall('GetPlanningInfo', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetPlanningInfo;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetStartAutomatism
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetStartAutomatism $parameters
     * @return \NOUT\Soap\StructType\GetStartAutomatismResponse|bool
     */
    public function GetStartAutomatism(\NOUT\Soap\StructType\GetStartAutomatism $parameters)
    {
        try {
            $this->setResult($resultGetStartAutomatism = $this->getSoapClient()->__soapCall('GetStartAutomatism', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetStartAutomatism;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetSubListContent
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetSubListContent $parameters
     * @return \NOUT\Soap\StructType\GetSubListContentResponse|bool
     */
    public function GetSubListContent(\NOUT\Soap\StructType\GetSubListContent $parameters)
    {
        try {
            $this->setResult($resultGetSubListContent = $this->getSoapClient()->__soapCall('GetSubListContent', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetSubListContent;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetTableChild
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetTableChild $parameters
     * @return \NOUT\Soap\StructType\GetTableChildResponse|bool
     */
    public function GetTableChild(\NOUT\Soap\StructType\GetTableChild $parameters)
    {
        try {
            $this->setResult($resultGetTableChild = $this->getSoapClient()->__soapCall('GetTableChild', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetTableChild;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetTemporalAutomatism
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $getTemporalAutomatism
     * @return \NOUT\Soap\StructType\GetTemporalAutomatismResponse|bool
     */
    public function GetTemporalAutomatism(\NOUT\Soap\StructType\EmptyType$getTemporalAutomatism)
    {
        try {
            $this->setResult($resultGetTemporalAutomatism = $this->getSoapClient()->__soapCall('GetTemporalAutomatism', [
                $getTemporalAutomatism,
            ], [], [], $this->outputHeaders));
        
            return $resultGetTemporalAutomatism;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named HasChanged
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $hasChanged
     * @return \NOUT\Soap\StructType\HasChangedResponse|bool
     */
    public function HasChanged(\NOUT\Soap\StructType\EmptyType $hasChanged)
    {
        try {
            $this->setResult($resultHasChanged = $this->getSoapClient()->__soapCall('HasChanged', [
                $hasChanged,
            ], [], [], $this->outputHeaders));
        
            return $resultHasChanged;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Import
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Import $parameters
     * @return \NOUT\Soap\StructType\ImportResponse|bool
     */
    public function Import(\NOUT\Soap\StructType\Import $parameters)
    {
        try {
            $this->setResult($resultImport = $this->getSoapClient()->__soapCall('Import', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultImport;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named List
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\_List $parameters
     * @return \NOUT\Soap\StructType\ListResponse|bool
     */
    public function _List(\NOUT\Soap\StructType\_List $parameters)
    {
        try {
            $this->setResult($resultList = $this->getSoapClient()->__soapCall('List', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Merge
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Merge $parameters
     * @return \NOUT\Soap\StructType\MergeResponse|bool
     */
    public function Merge(\NOUT\Soap\StructType\Merge $parameters)
    {
        try {
            $this->setResult($resultMerge = $this->getSoapClient()->__soapCall('Merge', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultMerge;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Modify
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Modify $parameters
     * @return \NOUT\Soap\StructType\ModifyResponse|bool
     */
    public function Modify(\NOUT\Soap\StructType\Modify $parameters)
    {
        try {
            $this->setResult($resultModify = $this->getSoapClient()->__soapCall('Modify', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultModify;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Paste
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Paste $parameters
     * @return \NOUT\Soap\StructType\PasteResponse|bool
     */
    public function Paste(\NOUT\Soap\StructType\Paste $parameters)
    {
        try {
            $this->setResult($resultPaste = $this->getSoapClient()->__soapCall('Paste', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultPaste;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Print
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\_Print $parameters
     * @return \NOUT\Soap\StructType\PrintResponse|bool
     */
    public function _Print(\NOUT\Soap\StructType\_Print $parameters)
    {
        try {
            $this->setResult($resultPrint = $this->getSoapClient()->__soapCall('Print', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultPrint;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ReorderList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ReorderList $parameters
     * @return \NOUT\Soap\StructType\ReorderListResponse|bool
     */
    public function ReorderList(\NOUT\Soap\StructType\ReorderList $parameters)
    {
        try {
            $this->setResult($resultReorderList = $this->getSoapClient()->__soapCall('ReorderList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultReorderList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ReorderSubList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ReorderSubList $parameters
     * @return \NOUT\Soap\StructType\ReorderSubListResponse|bool
     */
    public function ReorderSubList(\NOUT\Soap\StructType\ReorderSubList $parameters)
    {
        try {
            $this->setResult($resultReorderSubList = $this->getSoapClient()->__soapCall('ReorderSubList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultReorderSubList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Request
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Request $parameters
     * @return \NOUT\Soap\StructType\RequestResponse|bool
     */
    public function Request(\NOUT\Soap\StructType\Request $parameters)
    {
        try {
            $this->setResult($resultRequest = $this->getSoapClient()->__soapCall('Request', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultRequest;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named RequestParam
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\RequestParam $parameters
     * @return \NOUT\Soap\StructType\RequestParamResponse|bool
     */
    public function RequestParam(\NOUT\Soap\StructType\RequestParam $parameters)
    {
        try {
            $this->setResult($resultRequestParam = $this->getSoapClient()->__soapCall('RequestParam', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultRequestParam;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Search
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Search $parameters
     * @return \NOUT\Soap\StructType\SearchResponse|bool
     */
    public function Search(\NOUT\Soap\StructType\Search $parameters)
    {
        try {
            $this->setResult($resultSearch = $this->getSoapClient()->__soapCall('Search', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSearch;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SelectChoice
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SelectChoice $parameters
     * @return \NOUT\Soap\StructType\SelectChoiceResponse|bool
     */
    public function SelectChoice(\NOUT\Soap\StructType\SelectChoice $parameters)
    {
        try {
            $this->setResult($resultSelectChoice = $this->getSoapClient()->__soapCall('SelectChoice', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSelectChoice;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SelectForm
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SelectForm $parameters
     * @return \NOUT\Soap\StructType\SelectFormResponse|bool
     */
    public function SelectForm(\NOUT\Soap\StructType\SelectForm $parameters)
    {
        try {
            $this->setResult($resultSelectForm = $this->getSoapClient()->__soapCall('SelectForm', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSelectForm;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SelectItems
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SelectItems $parameters
     * @return \NOUT\Soap\StructType\SelectItemsResponse|bool
     */
    public function SelectItems(\NOUT\Soap\StructType\SelectItems $parameters)
    {
        try {
            $this->setResult($resultSelectItems = $this->getSoapClient()->__soapCall('SelectItems', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSelectItems;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SelectPrintTemplate
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SelectPrintTemplate $parameters
     * @return \NOUT\Soap\StructType\SelectPrintTemplateResponse|bool
     */
    public function SelectPrintTemplate(\NOUT\Soap\StructType\SelectPrintTemplate $parameters)
    {
        try {
            $this->setResult($resultSelectPrintTemplate = $this->getSoapClient()->__soapCall('SelectPrintTemplate', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSelectPrintTemplate;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SetOrderList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SetOrderList $parameters
     * @return \NOUT\Soap\StructType\SetOrderListResponse|bool
     */
    public function SetOrderList(\NOUT\Soap\StructType\SetOrderList $parameters)
    {
        try {
            $this->setResult($resultSetOrderList = $this->getSoapClient()->__soapCall('SetOrderList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSetOrderList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SetOrderSubList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SetOrderSubList $parameters
     * @return \NOUT\Soap\StructType\SetOrderSubListResponse|bool
     */
    public function SetOrderSubList(\NOUT\Soap\StructType\SetOrderSubList $parameters)
    {
        try {
            $this->setResult($resultSetOrderSubList = $this->getSoapClient()->__soapCall('SetOrderSubList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSetOrderSubList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named TransformInto
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\TransformInto $parameters
     * @return \NOUT\Soap\StructType\TransformIntoResponse|bool
     */
    public function TransformInto(\NOUT\Soap\StructType\TransformInto $parameters)
    {
        try {
            $this->setResult($resultTransformInto = $this->getSoapClient()->__soapCall('TransformInto', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultTransformInto;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Update
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Update $parameters
     * @return \NOUT\Soap\StructType\UpdateResponse|bool
     */
    public function Update(\NOUT\Soap\StructType\Update $parameters)
    {
        try {
            $this->setResult($resultUpdate = $this->getSoapClient()->__soapCall('Update', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUpdate;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named UpdateFilter
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\UpdateFilter $parameters
     * @return \NOUT\Soap\StructType\UpdateFilterResponse|bool
     */
    public function UpdateFilter(\NOUT\Soap\StructType\UpdateFilter $parameters)
    {
        try {
            $this->setResult($resultUpdateFilter = $this->getSoapClient()->__soapCall('UpdateFilter', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUpdateFilter;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Validate
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $validate
     * @return \NOUT\Soap\StructType\ValidateResponse|bool
     */
    public function Validate(\NOUT\Soap\StructType\EmptyType $validate)
    {
        try {
            $this->setResult($resultValidate = $this->getSoapClient()->__soapCall('Validate', [
                $validate,
            ], [], [], $this->outputHeaders));
        
            return $resultValidate;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named AddPJ
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\AddPJ $parameters
     * @return \NOUT\Soap\StructType\AddPJResponse|bool
     */
    public function AddPJ(\NOUT\Soap\StructType\AddPJ $parameters)
    {
        try {
            $this->setResult($resultAddPJ = $this->getSoapClient()->__soapCall('AddPJ', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultAddPJ;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CancelFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CancelFolder $parameters
     * @return CancelFolderResponse|bool
     */
    public function CancelFolder(\NOUT\Soap\StructType\CancelFolder $parameters)
    {
        try {
            $this->setResult($resultCancelFolder = $this->getSoapClient()->__soapCall('CancelFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCancelFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CancelMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CancelMessage $parameters
     * @return CancelMessageResponse|bool
     */
    public function CancelMessage(\NOUT\Soap\StructType\CancelMessage $parameters)
    {
        try {
            $this->setResult($resultCancelMessage = $this->getSoapClient()->__soapCall('CancelMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCancelMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CheckCreateElement
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CheckCreateElement $parameters
     * @return \NOUT\Soap\StructType\CheckCreateElementResponse|bool
     */
    public function CheckCreateElement(\NOUT\Soap\StructType\CheckCreateElement $parameters)
    {
        try {
            $this->setResult($resultCheckCreateElement = $this->getSoapClient()->__soapCall('CheckCreateElement', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCheckCreateElement;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CheckRecipient
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CheckRecipient $parameters
     * @return \NOUT\Soap\StructType\CheckRecipientResponse|bool
     */
    public function CheckRecipient(\NOUT\Soap\StructType\CheckRecipient $parameters)
    {
        try {
            $this->setResult($resultCheckRecipient = $this->getSoapClient()->__soapCall('CheckRecipient', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCheckRecipient;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CloseFolderList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CloseFolderList $parameters
     * @return CloseFolderListResponse|bool
     */
    public function CloseFolderList(\NOUT\Soap\StructType\CloseFolderList $parameters)
    {
        try {
            $this->setResult($resultCloseFolderList = $this->getSoapClient()->__soapCall('CloseFolderList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCloseFolderList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CloseMessageList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CloseMessageList $parameters
     * @return CloseMessageListResponse|bool
     */
    public function CloseMessageList(\NOUT\Soap\StructType\CloseMessageList $parameters)
    {
        try {
            $this->setResult($resultCloseMessageList = $this->getSoapClient()->__soapCall('CloseMessageList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCloseMessageList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CreateFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $createFolder
     * @return \NOUT\Soap\StructType\CreateFolderResponse|bool
     */
    public function CreateFolder(\NOUT\Soap\StructType\EmptyType $createFolder)
    {
        try {
            $this->setResult($resultCreateFolder = $this->getSoapClient()->__soapCall('CreateFolder', [
                $createFolder,
            ], [], [], $this->outputHeaders));
        
            return $resultCreateFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named CreateMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\CreateMessage $parameters
     * @return \NOUT\Soap\StructType\CreateMessageResponse|bool
     */
    public function CreateMessage(\NOUT\Soap\StructType\CreateMessage $parameters)
    {
        try {
            $this->setResult($resultCreateMessage = $this->getSoapClient()->__soapCall('CreateMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultCreateMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DeleteFolder
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DeleteFolder $parameters
     * @return DeleteFolderResponse|bool
     */
    public function DeleteFolder(\NOUT\Soap\StructType\DeleteFolder $parameters)
    {
        try {
            $this->setResult($resultDeleteFolder = $this->getSoapClient()->__soapCall('DeleteFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDeleteFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DeleteMessage
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DeleteMessage $parameters
     * @return DeleteMessageResponse|bool
     */
    public function DeleteMessage(\NOUT\Soap\StructType\DeleteMessage $parameters)
    {
        try {
            $this->setResult($resultDeleteMessage = $this->getSoapClient()->__soapCall('DeleteMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDeleteMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DeletePJ
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DeletePJ $parameters
     * @return \NOUT\Soap\StructType\DeletePJResponse|bool
     */
    public function DeletePJ(\NOUT\Soap\StructType\DeletePJ $parameters)
    {
        try {
            $this->setResult($resultDeletePJ = $this->getSoapClient()->__soapCall('DeletePJ', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDeletePJ;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DisplayRedoMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DisplayRedoMessage $parameters
     * @return \NOUT\Soap\StructType\DisplayRedoMessageResponse|bool
     */
    public function DisplayRedoMessage(\NOUT\Soap\StructType\DisplayRedoMessage $parameters)
    {
        try {
            $this->setResult($resultDisplayRedoMessage = $this->getSoapClient()->__soapCall('DisplayRedoMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDisplayRedoMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named DisplayUndoMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\DisplayUndoMessage $parameters
     * @return \NOUT\Soap\StructType\DisplayUndoMessageResponse|bool
     */
    public function DisplayUndoMessage(\NOUT\Soap\StructType\DisplayUndoMessage $parameters)
    {
        try {
            $this->setResult($resultDisplayUndoMessage = $this->getSoapClient()->__soapCall('DisplayUndoMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultDisplayUndoMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetContentFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetContentFolder $parameters
     * @return \NOUT\Soap\StructType\GetContentFolderResponse|bool
     */
    public function GetContentFolder(\NOUT\Soap\StructType\GetContentFolder $parameters)
    {
        try {
            $this->setResult($resultGetContentFolder = $this->getSoapClient()->__soapCall('GetContentFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetContentFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetFolderList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $getFolderList
     * @return \NOUT\Soap\StructType\GetFolderListResponse|bool
     */
    public function GetFolderList(\NOUT\Soap\StructType\EmptyType $getFolderList)
    {
        try {
            $this->setResult($resultGetFolderList = $this->getSoapClient()->__soapCall('GetFolderList', [
                $getFolderList,
            ], [], [], $this->outputHeaders));
        
            return $resultGetFolderList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetListIDMessFromFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetListIDMessFromFolder $parameters
     * @return \NOUT\Soap\StructType\GetListIDMessFromFolderResponse|bool
     */
    public function GetListIDMessFromFolder(\NOUT\Soap\StructType\GetListIDMessFromFolder $parameters)
    {
        try {
            $this->setResult($resultGetListIDMessFromFolder = $this->getSoapClient()->__soapCall('GetListIDMessFromFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetListIDMessFromFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetListIDMessFromRequest
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetListIDMessFromRequest $parameters
     * @return \NOUT\Soap\StructType\GetListIDMessFromRequestResponse|bool
     */
    public function GetListIDMessFromRequest(\NOUT\Soap\StructType\GetListIDMessFromRequest $parameters)
    {
        try {
            $this->setResult($resultGetListIDMessFromRequest = $this->getSoapClient()->__soapCall('GetListIDMessFromRequest', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetListIDMessFromRequest;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetListMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetListMessage $parameters
     * @return \NOUT\Soap\StructType\GetListMessageResponse|bool
     */
    public function GetListMessage(\NOUT\Soap\StructType\GetListMessage $parameters)
    {
        try {
            $this->setResult($resultGetListMessage = $this->getSoapClient()->__soapCall('GetListMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetListMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetMailServiceStatus
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\EmptyType $getMailServiceStatus
     * @return \NOUT\Soap\StructType\GetMailServiceStatusResponse|bool
     */
    public function GetMailServiceStatus(\NOUT\Soap\StructType\EmptyType $getMailServiceStatus)
    {
        try {
            $this->setResult($resultGetMailServiceStatus = $this->getSoapClient()->__soapCall('GetMailServiceStatus', [
                $getMailServiceStatus,
            ], [], [], $this->outputHeaders));
        
            return $resultGetMailServiceStatus;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetMessagesFromListID
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetMessagesFromListID $parameters
     * @return \NOUT\Soap\StructType\GetMessagesFromListIDResponse|bool
     */
    public function GetMessagesFromListID(\NOUT\Soap\StructType\GetMessagesFromListID $parameters)
    {
        try {
            $this->setResult($resultGetMessagesFromListID = $this->getSoapClient()->__soapCall('GetMessagesFromListID', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetMessagesFromListID;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetPJ
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetPJ $parameters
     * @return \NOUT\Soap\StructType\GetPJResponse|bool
     */
    public function GetPJ(\NOUT\Soap\StructType\GetPJ $parameters)
    {
        try {
            $this->setResult($resultGetPJ = $this->getSoapClient()->__soapCall('GetPJ', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetPJ;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetRedoList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetRedoList $parameters
     * @return \NOUT\Soap\StructType\GetRedoListResponse|bool
     */
    public function GetRedoList(\NOUT\Soap\StructType\GetRedoList $parameters)
    {
        try {
            $this->setResult($resultGetRedoList = $this->getSoapClient()->__soapCall('GetRedoList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetRedoList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetRedoListID
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetRedoListID $parameters
     * @return \NOUT\Soap\StructType\GetRedoListIDResponse|bool
     */
    public function GetRedoListID(\NOUT\Soap\StructType\GetRedoListID $parameters)
    {
        try {
            $this->setResult($resultGetRedoListID = $this->getSoapClient()->__soapCall('GetRedoListID', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetRedoListID;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetUndoList
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetUndoList $parameters
     * @return \NOUT\Soap\StructType\GetUndoListResponse|bool
     */
    public function GetUndoList(\NOUT\Soap\StructType\GetUndoList $parameters)
    {
        try {
            $this->setResult($resultGetUndoList = $this->getSoapClient()->__soapCall('GetUndoList', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetUndoList;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named GetUndoListID
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\GetUndoListID $parameters
     * @return \NOUT\Soap\StructType\GetUndoListIDResponse|bool
     */
    public function GetUndoListID(\NOUT\Soap\StructType\GetUndoListID $parameters)
    {
        try {
            $this->setResult($resultGetUndoListID = $this->getSoapClient()->__soapCall('GetUndoListID', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultGetUndoListID;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ModifyFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ModifyFolder $parameters
     * @return \NOUT\Soap\StructType\ModifyFolderResponse|bool
     */
    public function ModifyFolder(\NOUT\Soap\StructType\ModifyFolder $parameters)
    {
        try {
            $this->setResult($resultModifyFolder = $this->getSoapClient()->__soapCall('ModifyFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultModifyFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ModifyMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ModifyMessage $parameters
     * @return \NOUT\Soap\StructType\ModifyMessageResponse|bool
     */
    public function ModifyMessage(\NOUT\Soap\StructType\ModifyMessage $parameters)
    {
        try {
            $this->setResult($resultModifyMessage = $this->getSoapClient()->__soapCall('ModifyMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultModifyMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Redo
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Redo $parameters
     * @return \NOUT\Soap\StructType\RedoResponse|bool
     */
    public function Redo(\NOUT\Soap\StructType\Redo $parameters)
    {
        try {
            $this->setResult($resultRedo = $this->getSoapClient()->__soapCall('Redo', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultRedo;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named RequestMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate, ActionContext
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate, \NOUT\Soap\StructType\ActionContext
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\RequestMessage $parameters
     * @return \NOUT\Soap\StructType\RequestMessageResponse|bool
     */
    public function RequestMessage(\NOUT\Soap\StructType\RequestMessage $parameters)
    {
        try {
            $this->setResult($resultRequestMessage = $this->getSoapClient()->__soapCall('RequestMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultRequestMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named SendMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\SendMessage $parameters
     * @return \NOUT\Soap\StructType\SendMessageResponse|bool
     */
    public function SendMessage(\NOUT\Soap\StructType\SendMessage $parameters)
    {
        try {
            $this->setResult($resultSendMessage = $this->getSoapClient()->__soapCall('SendMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultSendMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named Undo
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\Undo $parameters
     * @return \NOUT\Soap\StructType\UndoResponse|bool
     */
    public function Undo(\NOUT\Soap\StructType\Undo $parameters)
    {
        try {
            $this->setResult($resultUndo = $this->getSoapClient()->__soapCall('Undo', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUndo;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named UpdateColumnMessageValueInBatch
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\UpdateColumnMessageValueInBatch $parameters
     * @return \NOUT\Soap\StructType\UpdateColumnMessageValueInBatchResponse|bool
     */
    public function UpdateColumnMessageValueInBatch(\NOUT\Soap\StructType\UpdateColumnMessageValueInBatch $parameters)
    {
        try {
            $this->setResult($resultUpdateColumnMessageValueInBatch = $this->getSoapClient()->__soapCall('UpdateColumnMessageValueInBatch', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUpdateColumnMessageValueInBatch;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named UpdateFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\UpdateFolder $parameters
     * @return \NOUT\Soap\StructType\UpdateFolderResponse|bool
     */
    public function UpdateFolder(\NOUT\Soap\StructType\UpdateFolder $parameters)
    {
        try {
            $this->setResult($resultUpdateFolder = $this->getSoapClient()->__soapCall('UpdateFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUpdateFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named UpdateMessage
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken, AutoValidate
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType, \NOUT\Soap\StructType\AutoValidate
     * - SOAPHeaders: optional, optional, optional, optional, required, required, optional
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\UpdateMessage $parameters
     * @return \NOUT\Soap\StructType\UpdateMessageResponse|bool
     */
    public function UpdateMessage(\NOUT\Soap\StructType\UpdateMessage $parameters)
    {
        try {
            $this->setResult($resultUpdateMessage = $this->getSoapClient()->__soapCall('UpdateMessage', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultUpdateMessage;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ValidateFolder
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ValidateFolder $parameters
     * @return ValidateFolderResponse|bool
     */
    public function ValidateFolder(\NOUT\Soap\StructType\ValidateFolder $parameters)
    {
        try {
            $this->setResult($resultValidateFolder = $this->getSoapClient()->__soapCall('ValidateFolder', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultValidateFolder;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named WithAutomaticResponse
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\WithAutomaticResponse $parameters
     * @return \NOUT\Soap\StructType\WithAutomaticResponseResponse|bool
     */
    public function WithAutomaticResponse(\NOUT\Soap\StructType\WithAutomaticResponse $parameters)
    {
        try {
            $this->setResult($resultWithAutomaticResponse = $this->getSoapClient()->__soapCall('WithAutomaticResponse', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultWithAutomaticResponse;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Method to call the operation originally named ZipPJ
     * Meta information extracted from the WSDL
     * - SOAPHeaderNames: APIUUID, CustomerInfos, OptionDialogue, APIUser, SessionToken, UsernameToken
     * - SOAPHeaderNamespaces: http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/, http://www.nout.fr/wsdl/SimaxService.wsdl/
     * - SOAPHeaderTypes: \NOUT\Soap\StructType\APIUUID, \NOUT\Soap\StructType\CustomerInfos, \NOUT\Soap\StructType\OptionDialogue, \NOUT\Soap\StructType\APIUser, \NOUT\Soap\StructType\SessionToken, \NOUT\Soap\StructType\UsernameTokenType
     * - SOAPHeaders: optional, optional, optional, optional, required, required
     * @uses AbstractSoapClientBase::getSoapClient()
     * @uses AbstractSoapClientBase::setResult()
     * @uses AbstractSoapClientBase::saveLastError()
     * @param \NOUT\Soap\StructType\ZipPJ $parameters
     * @return \NOUT\Soap\StructType\ZipPJResponse|bool
     */
    public function ZipPJ(\NOUT\Soap\StructType\ZipPJ $parameters)
    {
        try {
            $this->setResult($resultZipPJ = $this->getSoapClient()->__soapCall('ZipPJ', [
                $parameters,
            ], [], [], $this->outputHeaders));
        
            return $resultZipPJ;
        } catch (SoapFault $soapFault) {
            $this->saveLastError(__METHOD__, $soapFault);
        
            return false;
        }
    }
    /**
     * Returns the result
     * @see AbstractSoapClientBase::getResult()
     * @return CancelFolderResponse|CancelMessageResponse|CloseFolderListResponse|CloseMessageListResponse|DeleteFolderResponse|DeleteMessageResponse|DisconnectResponse|ValidateFolderResponse|\NOUT\Soap\StructType\ActionFromMessageResponse|\NOUT\Soap\StructType\AddPJResponse|\NOUT\Soap\StructType\AuditActionResponse|\NOUT\Soap\StructType\AutoCompleteResponse|\NOUT\Soap\StructType\ButtonActionResponse|\NOUT\Soap\StructType\CancelResponse|\NOUT\Soap\StructType\CheckCreateElementResponse|\NOUT\Soap\StructType\CheckCtrlResponse|\NOUT\Soap\StructType\CheckRecipientResponse|\NOUT\Soap\StructType\ConfirmResponseResponse|\NOUT\Soap\StructType\CopyResponse|\NOUT\Soap\StructType\CreateFolderResponse|\NOUT\Soap\StructType\CreateFromResponse|\NOUT\Soap\StructType\CreateMessageResponse|\NOUT\Soap\StructType\CreateResponse|\NOUT\Soap\StructType\DeletePJResponse|\NOUT\Soap\StructType\DeleteResponse|\NOUT\Soap\StructType\DisplayRedoMessageResponse|\NOUT\Soap\StructType\DisplayResponse|\NOUT\Soap\StructType\DisplayUndoMessageResponse|\NOUT\Soap\StructType\DrillThroughResponse|\NOUT\Soap\StructType\EnterReorderListModeResponse|\NOUT\Soap\StructType\ExecuteResponse|\NOUT\Soap\StructType\ExecuteWithoutIHMResponse|\NOUT\Soap\StructType\ExportResponse|\NOUT\Soap\StructType\GetCalculationResponse|\NOUT\Soap\StructType\GetChartResponse|\NOUT\Soap\StructType\GetColInRecordResponse|\NOUT\Soap\StructType\GetContentFolderResponse|\NOUT\Soap\StructType\GetEndAutomatismResponse|\NOUT\Soap\StructType\GetEndListCalculationResponse|\NOUT\Soap\StructType\GetFolderListResponse|\NOUT\Soap\StructType\GetLanguagesResponse|\NOUT\Soap\StructType\GetListIDMessFromFolderResponse|\NOUT\Soap\StructType\GetListIDMessFromRequestResponse|\NOUT\Soap\StructType\GetListMessageResponse|\NOUT\Soap\StructType\GetMailServiceStatusResponse|\NOUT\Soap\StructType\GetMessagesFromListIDResponse|\NOUT\Soap\StructType\GetPJResponse|\NOUT\Soap\StructType\GetPlanningInfoResponse|\NOUT\Soap\StructType\GetRedoListIDResponse|\NOUT\Soap\StructType\GetRedoListResponse|\NOUT\Soap\StructType\GetStartAutomatismResponse|\NOUT\Soap\StructType\GetSubListContentResponse|\NOUT\Soap\StructType\GetTableChildResponse|\NOUT\Soap\StructType\GetTemporalAutomatismResponse|\NOUT\Soap\StructType\GetTokenSessionResponse|\NOUT\Soap\StructType\GetUndoListIDResponse|\NOUT\Soap\StructType\GetUndoListResponse|\NOUT\Soap\StructType\HasChangedResponse|\NOUT\Soap\StructType\ImportResponse|\NOUT\Soap\StructType\InitRecordFromAddressResponse|\NOUT\Soap\StructType\InitRecordFromMessageResponse|\NOUT\Soap\StructType\ListResponse|\NOUT\Soap\StructType\MergeResponse|\NOUT\Soap\StructType\ModifyFolderResponse|\NOUT\Soap\StructType\ModifyMessageResponse|\NOUT\Soap\StructType\ModifyResponse|\NOUT\Soap\StructType\PasteResponse|\NOUT\Soap\StructType\PrintResponse|\NOUT\Soap\StructType\RedoResponse|\NOUT\Soap\StructType\ReorderListResponse|\NOUT\Soap\StructType\ReorderSubListResponse|\NOUT\Soap\StructType\RequestMessageResponse|\NOUT\Soap\StructType\RequestParamResponse|\NOUT\Soap\StructType\RequestResponse|\NOUT\Soap\StructType\ResetPasswordFailedResponse|\NOUT\Soap\StructType\SearchResponse|\NOUT\Soap\StructType\SelectChoiceResponse|\NOUT\Soap\StructType\SelectFormResponse|\NOUT\Soap\StructType\SelectItemsResponse|\NOUT\Soap\StructType\SelectPrintTemplateResponse|\NOUT\Soap\StructType\SendMessageResponse|\NOUT\Soap\StructType\SetOrderListResponse|\NOUT\Soap\StructType\SetOrderSubListResponse|\NOUT\Soap\StructType\TransformIntoResponse|\NOUT\Soap\StructType\UndoResponse|\NOUT\Soap\StructType\UpdateColumnMessageValueInBatchResponse|\NOUT\Soap\StructType\UpdateFilterResponse|\NOUT\Soap\StructType\UpdateFolderResponse|\NOUT\Soap\StructType\UpdateMessageResponse|\NOUT\Soap\StructType\UpdateResponse|\NOUT\Soap\StructType\ValidateResponse|\NOUT\Soap\StructType\WithAutomaticResponseResponse|\NOUT\Soap\StructType\ZipPJResponse
     */
    public function getResult()
    {
        return parent::getResult();
    }
}
