<?php

declare(strict_types=1);

namespace NOUT\Soap\StructType;

use InvalidArgumentException;
use NOUT\Soap\PackageBase\AbstractStructBase;

/**
 * This class stands for ButtonAction StructType
 * @subpackage Structs
 */
#[\AllowDynamicProperties]
class ButtonAction extends AbstractStructBase
{
    /**
     * The CallingColumn
     * @var string|null
     */
    protected ?string $CallingColumn = null;
    /**
     * The CallingInfo
     * Meta information extracted from the WSDL
     * - minOccurs: 0
     * @var \NOUT\Soap\StructType\CallingInfoType|null
     */
    protected ?\NOUT\Soap\StructType\CallingInfoType $CallingInfo = null;
    /**
     * The ColumnSelection
     * Meta information extracted from the WSDL
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \NOUT\Soap\StructType\ColumnSelection[]
     */
    protected ?array $ColumnSelection = null;
    /**
     * Constructor method for ButtonAction
     * @uses ButtonAction::setCallingColumn()
     * @uses ButtonAction::setCallingInfo()
     * @uses ButtonAction::setColumnSelection()
     * @param string $callingColumn
     * @param \NOUT\Soap\StructType\CallingInfoType $callingInfo
     * @param \NOUT\Soap\StructType\ColumnSelection[] $columnSelection
     */
    public function __construct(?string $callingColumn = null, ?\NOUT\Soap\StructType\CallingInfoType $callingInfo = null, ?array $columnSelection = null)
    {
        $this
            ->setCallingColumn($callingColumn)
            ->setCallingInfo($callingInfo)
            ->setColumnSelection($columnSelection);
    }
    /**
     * Get CallingColumn value
     * @return string|null
     */
    public function getCallingColumn(): ?string
    {
        return $this->CallingColumn;
    }
    /**
     * Set CallingColumn value
     * @param string $callingColumn
     * @return \NOUT\Soap\StructType\ButtonAction
     */
    public function setCallingColumn(?string $callingColumn = null): self
    {
        // validation for constraint: string
        if (!is_null($callingColumn) && !is_string($callingColumn)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($callingColumn, true), gettype($callingColumn)), __LINE__);
        }
        $this->CallingColumn = $callingColumn;
        
        return $this;
    }
    /**
     * Get CallingInfo value
     * @return \NOUT\Soap\StructType\CallingInfoType|null
     */
    public function getCallingInfo(): ?\NOUT\Soap\StructType\CallingInfoType
    {
        return $this->CallingInfo;
    }
    /**
     * Set CallingInfo value
     * @param \NOUT\Soap\StructType\CallingInfoType $callingInfo
     * @return \NOUT\Soap\StructType\ButtonAction
     */
    public function setCallingInfo(?\NOUT\Soap\StructType\CallingInfoType $callingInfo = null): self
    {
        $this->CallingInfo = $callingInfo;
        
        return $this;
    }
    /**
     * Get ColumnSelection value
     * @return \NOUT\Soap\StructType\ColumnSelection[]
     */
    public function getColumnSelection(): ?array
    {
        return $this->ColumnSelection;
    }
    /**
     * This method is responsible for validating the value(s) passed to the setColumnSelection method
     * This method is willingly generated in order to preserve the one-line inline validation within the setColumnSelection method
     * This has to validate that each item contained by the array match the itemType constraint
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateColumnSelectionForArrayConstraintFromSetColumnSelection(?array $values = []): string
    {
        if (!is_array($values)) {
            return '';
        }
        $message = '';
        $invalidValues = [];
        foreach ($values as $buttonActionColumnSelectionItem) {
            // validation for constraint: itemType
            if (!$buttonActionColumnSelectionItem instanceof \NOUT\Soap\StructType\ColumnSelection) {
                $invalidValues[] = is_object($buttonActionColumnSelectionItem) ? get_class($buttonActionColumnSelectionItem) : sprintf('%s(%s)', gettype($buttonActionColumnSelectionItem), var_export($buttonActionColumnSelectionItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The ColumnSelection property can only contain items of type \NOUT\Soap\StructType\ColumnSelection, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        
        return $message;
    }
    /**
     * Set ColumnSelection value
     * @throws InvalidArgumentException
     * @param \NOUT\Soap\StructType\ColumnSelection[] $columnSelection
     * @return \NOUT\Soap\StructType\ButtonAction
     */
    public function setColumnSelection(?array $columnSelection = null): self
    {
        // validation for constraint: array
        if ('' !== ($columnSelectionArrayErrorMessage = self::validateColumnSelectionForArrayConstraintFromSetColumnSelection($columnSelection))) {
            throw new InvalidArgumentException($columnSelectionArrayErrorMessage, __LINE__);
        }
        $this->ColumnSelection = $columnSelection;
        
        return $this;
    }
    /**
     * Add item to ColumnSelection value
     * @throws InvalidArgumentException
     * @param \NOUT\Soap\StructType\ColumnSelection $item
     * @return \NOUT\Soap\StructType\ButtonAction
     */
    public function addToColumnSelection(\NOUT\Soap\StructType\ColumnSelection $item): self
    {
        // validation for constraint: itemType
        if (!$item instanceof \NOUT\Soap\StructType\ColumnSelection) {
            throw new InvalidArgumentException(sprintf('The ColumnSelection property can only contain items of type \NOUT\Soap\StructType\ColumnSelection, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->ColumnSelection[] = $item;
        
        return $this;
    }
}
