<?php

declare(strict_types=1);

namespace NOUT\Soap\StructType;

use InvalidArgumentException;
use NOUT\Soap\PackageBase\AbstractStructBase;

/**
 * This class stands for ExtranetUserType StructType
 * @subpackage Structs
 */
#[\AllowDynamicProperties]
class ExtranetUserType extends AbstractStructBase
{
    /**
     * The UsernameToken
     * Meta information extracted from the WSDL
     * - choice: UsernameToken | Anonymous
     * - choiceMaxOccurs: 1
     * - choiceMinOccurs: 1
     * @var \NOUT\Soap\StructType\UsernameTokenType|null
     */
    protected ?\NOUT\Soap\StructType\UsernameTokenType $UsernameToken = null;
    /**
     * The Anonymous
     * Meta information extracted from the WSDL
     * - choice: UsernameToken | Anonymous
     * - choiceMaxOccurs: 1
     * - choiceMinOccurs: 1
     * @var int|null
     */
    protected ?int $Anonymous = null;
    /**
     * The Form
     * @var string|null
     */
    protected ?string $Form = null;
    /**
     * Constructor method for ExtranetUserType
     * @uses ExtranetUserType::setUsernameToken()
     * @uses ExtranetUserType::setAnonymous()
     * @uses ExtranetUserType::setForm()
     * @param \NOUT\Soap\StructType\UsernameTokenType $usernameToken
     * @param int $anonymous
     * @param string $form
     */
    public function __construct(?\NOUT\Soap\StructType\UsernameTokenType $usernameToken = null, ?int $anonymous = null, ?string $form = null)
    {
        $this
            ->setUsernameToken($usernameToken)
            ->setAnonymous($anonymous)
            ->setForm($form);
    }
    /**
     * Get UsernameToken value
     * @return \NOUT\Soap\StructType\UsernameTokenType|null
     */
    public function getUsernameToken(): ?\NOUT\Soap\StructType\UsernameTokenType
    {
        return $this->UsernameToken ?? null;
    }
    /**
     * This method is responsible for validating the value(s) passed to the setUsernameToken method
     * This method is willingly generated in order to preserve the one-line inline validation within the setUsernameToken method
     * This has to validate that the property which is being set is the only one among the given choices
     * @param mixed $value
     * @return string A non-empty message if the values does not match the validation rules
     */
    public function validateUsernameTokenForChoiceConstraintFromSetUsernameToken($value): string
    {
        $message = '';
        if (is_null($value)) {
            return $message;
        }
        $properties = [
            'Anonymous',
        ];
        try {
            foreach ($properties as $property) {
                if (isset($this->{$property})) {
                    throw new InvalidArgumentException(sprintf('The property UsernameToken can\'t be set as the property %s is already set. Only one property must be set among these properties: UsernameToken, %s.', $property, implode(', ', $properties)), __LINE__);
                }
            }
        } catch (InvalidArgumentException $e) {
            $message = $e->getMessage();
        }
        
        return $message;
    }
    /**
     * Set UsernameToken value
     * This property belongs to a choice that allows only one property to exist. It is
     * therefore removable from the request, consequently if the value assigned to this
     * property is null, the property is removed from this object
     * @throws InvalidArgumentException
     * @param \NOUT\Soap\StructType\UsernameTokenType $usernameToken
     * @return \NOUT\Soap\StructType\ExtranetUserType
     */
    public function setUsernameToken(?\NOUT\Soap\StructType\UsernameTokenType $usernameToken = null): self
    {
        // validation for constraint: choice(UsernameToken, Anonymous)
        if ('' !== ($usernameTokenChoiceErrorMessage = self::validateUsernameTokenForChoiceConstraintFromSetUsernameToken($usernameToken))) {
            throw new InvalidArgumentException($usernameTokenChoiceErrorMessage, __LINE__);
        }
        if (is_null($usernameToken) || (is_array($usernameToken) && empty($usernameToken))) {
            unset($this->UsernameToken);
        } else {
            $this->UsernameToken = $usernameToken;
        }
        
        return $this;
    }
    /**
     * Get Anonymous value
     * @return int|null
     */
    public function getAnonymous(): ?int
    {
        return $this->Anonymous ?? null;
    }
    /**
     * This method is responsible for validating the value(s) passed to the setAnonymous method
     * This method is willingly generated in order to preserve the one-line inline validation within the setAnonymous method
     * This has to validate that the property which is being set is the only one among the given choices
     * @param mixed $value
     * @return string A non-empty message if the values does not match the validation rules
     */
    public function validateAnonymousForChoiceConstraintFromSetAnonymous($value): string
    {
        $message = '';
        if (is_null($value)) {
            return $message;
        }
        $properties = [
            'UsernameToken',
        ];
        try {
            foreach ($properties as $property) {
                if (isset($this->{$property})) {
                    throw new InvalidArgumentException(sprintf('The property Anonymous can\'t be set as the property %s is already set. Only one property must be set among these properties: Anonymous, %s.', $property, implode(', ', $properties)), __LINE__);
                }
            }
        } catch (InvalidArgumentException $e) {
            $message = $e->getMessage();
        }
        
        return $message;
    }
    /**
     * Set Anonymous value
     * This property belongs to a choice that allows only one property to exist. It is
     * therefore removable from the request, consequently if the value assigned to this
     * property is null, the property is removed from this object
     * @throws InvalidArgumentException
     * @param int $anonymous
     * @return \NOUT\Soap\StructType\ExtranetUserType
     */
    public function setAnonymous(?int $anonymous = null): self
    {
        // validation for constraint: int
        if (!is_null($anonymous) && !(is_int($anonymous) || ctype_digit($anonymous))) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($anonymous, true), gettype($anonymous)), __LINE__);
        }
        // validation for constraint: choice(UsernameToken, Anonymous)
        if ('' !== ($anonymousChoiceErrorMessage = self::validateAnonymousForChoiceConstraintFromSetAnonymous($anonymous))) {
            throw new InvalidArgumentException($anonymousChoiceErrorMessage, __LINE__);
        }
        if (is_null($anonymous) || (is_array($anonymous) && empty($anonymous))) {
            unset($this->Anonymous);
        } else {
            $this->Anonymous = $anonymous;
        }
        
        return $this;
    }
    /**
     * Get Form value
     * @return string|null
     */
    public function getForm(): ?string
    {
        return $this->Form;
    }
    /**
     * Set Form value
     * @param string $form
     * @return \NOUT\Soap\StructType\ExtranetUserType
     */
    public function setForm(?string $form = null): self
    {
        // validation for constraint: string
        if (!is_null($form) && !is_string($form)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($form, true), gettype($form)), __LINE__);
        }
        $this->Form = $form;
        
        return $this;
    }
}
