<?php

declare(strict_types=1);

namespace NOUT\Soap\StructType;

use InvalidArgumentException;
use NOUT\Soap\PackageBase\AbstractStructBase;

/**
 * This class stands for ReorderList StructType
 * @subpackage Structs
 */
#[\AllowDynamicProperties]
class ReorderList extends AbstractStructBase
{
    /**
     * The items
     * @var string|null
     */
    protected ?string $items = null;
    /**
     * The moveType
     * @var string|null
     */
    protected ?string $moveType = null;
    /**
     * The scale
     * @var int|null
     */
    protected ?int $scale = null;
    /**
     * Constructor method for ReorderList
     * @uses ReorderList::setItems()
     * @uses ReorderList::setMoveType()
     * @uses ReorderList::setScale()
     * @param string $items
     * @param string $moveType
     * @param int $scale
     */
    public function __construct(?string $items = null, ?string $moveType = null, ?int $scale = null)
    {
        $this
            ->setItems($items)
            ->setMoveType($moveType)
            ->setScale($scale);
    }
    /**
     * Get items value
     * @return string|null
     */
    public function getItems(): ?string
    {
        return $this->items;
    }
    /**
     * Set items value
     * @param string $items
     * @return \NOUT\Soap\StructType\ReorderList
     */
    public function setItems(?string $items = null): self
    {
        // validation for constraint: string
        if (!is_null($items) && !is_string($items)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($items, true), gettype($items)), __LINE__);
        }
        $this->items = $items;
        
        return $this;
    }
    /**
     * Get moveType value
     * @return string|null
     */
    public function getMoveType(): ?string
    {
        return $this->moveType;
    }
    /**
     * Set moveType value
     * @param string $moveType
     * @return \NOUT\Soap\StructType\ReorderList
     */
    public function setMoveType(?string $moveType = null): self
    {
        // validation for constraint: string
        if (!is_null($moveType) && !is_string($moveType)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($moveType, true), gettype($moveType)), __LINE__);
        }
        $this->moveType = $moveType;
        
        return $this;
    }
    /**
     * Get scale value
     * @return int|null
     */
    public function getScale(): ?int
    {
        return $this->scale;
    }
    /**
     * Set scale value
     * @param int $scale
     * @return \NOUT\Soap\StructType\ReorderList
     */
    public function setScale(?int $scale = null): self
    {
        // validation for constraint: int
        if (!is_null($scale) && !(is_int($scale) || ctype_digit($scale))) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($scale, true), gettype($scale)), __LINE__);
        }
        $this->scale = $scale;
        
        return $this;
    }
}
