<?php

declare(strict_types=1);

namespace NOUT\Soap\StructType;

use InvalidArgumentException;
use NOUT\Soap\PackageBase\AbstractStructBase;

/**
 * This class stands for SetOrderSubList StructType
 * @subpackage Structs
 */
#[\AllowDynamicProperties]
class SetOrderSubList extends AbstractStructBase
{
    /**
     * The column
     * @var string|null
     */
    protected ?string $column = null;
    /**
     * The items
     * @var string|null
     */
    protected ?string $items = null;
    /**
     * The offset
     * @var int|null
     */
    protected ?int $offset = null;
    /**
     * Constructor method for SetOrderSubList
     * @uses SetOrderSubList::setColumn()
     * @uses SetOrderSubList::setItems()
     * @uses SetOrderSubList::setOffset()
     * @param string $column
     * @param string $items
     * @param int $offset
     */
    public function __construct(?string $column = null, ?string $items = null, ?int $offset = null)
    {
        $this
            ->setColumn($column)
            ->setItems($items)
            ->setOffset($offset);
    }
    /**
     * Get column value
     * @return string|null
     */
    public function getColumn(): ?string
    {
        return $this->column;
    }
    /**
     * Set column value
     * @param string $column
     * @return \NOUT\Soap\StructType\SetOrderSubList
     */
    public function setColumn(?string $column = null): self
    {
        // validation for constraint: string
        if (!is_null($column) && !is_string($column)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($column, true), gettype($column)), __LINE__);
        }
        $this->column = $column;
        
        return $this;
    }
    /**
     * Get items value
     * @return string|null
     */
    public function getItems(): ?string
    {
        return $this->items;
    }
    /**
     * Set items value
     * @param string $items
     * @return \NOUT\Soap\StructType\SetOrderSubList
     */
    public function setItems(?string $items = null): self
    {
        // validation for constraint: string
        if (!is_null($items) && !is_string($items)) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($items, true), gettype($items)), __LINE__);
        }
        $this->items = $items;
        
        return $this;
    }
    /**
     * Get offset value
     * @return int|null
     */
    public function getOffset(): ?int
    {
        return $this->offset;
    }
    /**
     * Set offset value
     * @param int $offset
     * @return \NOUT\Soap\StructType\SetOrderSubList
     */
    public function setOffset(?int $offset = null): self
    {
        // validation for constraint: int
        if (!is_null($offset) && !(is_int($offset) || ctype_digit($offset))) {
            throw new InvalidArgumentException(sprintf('Invalid value %s, please provide an integer value, %s given', var_export($offset, true), gettype($offset)), __LINE__);
        }
        $this->offset = $offset;
        
        return $this;
    }
}
