<?php

/**
 * class de constante (enum) permettant de lister les colonne de la bdd pour le plugin (simaxFormSubmiter)
 */
class sfs_clEnumDbCols
{
	const sIdRow 		= 'ID';
	const sTitle		= 'title';
	const sIdSimaxForm 	= 'id_simax_form';
	const sFormDesc 	= 'html_form_desc';
	const sError		= 'error_msg';
	const sSuccess		= 'success_msg';
	const sRecupMail	= 'sMailForRecup'; //adresse mail pour recuperation erreur
}

/**
 * class permettant de gerer les echange bdd pour le plugin (simaxFormSubmiter)
 */
class sfs_clDbGest
{
	const sDataBaseName = 'sfs-form-interact';

	//vrai nom de la bdd wp
	private $__sRealDbName;

	//chaine de charset et collation
	private $__sCharsetCollation;

	/**
	 * constructeur
	 */
	public function __construct()
	{
		global $wpdb, $table_prefix;
		$this->__sRealDbName = $table_prefix . self::sDataBaseName ;
	}

	/************************************************************************************************************/
	/*********** Gestion instalation/desinstallation bdd *********************************************************/

	/**
	 * fonction permettant l'installation de la base de donnée.
	 * (creation de la table avec les colonnes qui nous interesse)
	 */
	public function install_bdd()
	{
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

		$sCharsetCollate = $this->get_charset_collation();

		$sSql = 'CREATE TABLE `' . $this->__sRealDbName . '` (
		  `' . sfs_clEnumDbCols::sIdRow . '` int(11) NOT NULL AUTO_INCREMENT,
		  `' . sfs_clEnumDbCols::sTitle . '` text DEFAULT \'\' NOT NULL,
		  `' . sfs_clEnumDbCols::sIdSimaxForm . '` text DEFAULT \'\' NOT NULL,
		  `' . sfs_clEnumDbCols::sFormDesc . '` longtext DEFAULT \'\' NOT NULL,
		  `' . sfs_clEnumDbCols::sError . '` longtext DEFAULT \'\' NOT NULL,
		  `' . sfs_clEnumDbCols::sSuccess . '` longtext DEFAULT \'\' NOT NULL,
		  `' . sfs_clEnumDbCols::sRecupMail . '` longtext DEFAULT \'\' NOT NULL,
		  PRIMARY KEY (`' . sfs_clEnumDbCols::sIdRow . '`)
		) ' . $sCharsetCollate ;

		dbDelta($sSql);
	}

	/**
	 * fonction permettant la desinstallation de la bdd
	 */
	public function uninstall_bdd()
	{
		global $wpdb;


		$sSql = 'DROP TABLE `' . $this->__sRealDbName . '`';
		$wpdb->query($sSql);
	}

	/************************************************************************************************************/
	/*********** Fonction Sql creation/modificatin/suppression **************************************************/
	/**
	 * fonction permettant de creer un nouvel enregistrement vide
	 */
	public function create_empty_enreg()
	{
		global $wpdb;
		$sSql = 'INSERT INTO `' . $this->__sRealDbName . '` (`' . sfs_clEnumDbCols::sIdRow . '`,`' . sfs_clEnumDbCols::sTitle  . '`) VALUES (NULL,\'Sans titre\');';

		$wpdb->query($sSql);
	}

	/**
	 * fonction permettant de supprimer de multiple enregistrement
	 *
	 * @param array le tableau des id a supprimer
	 */
	public function multiple_delete($aIdList)
	{
		global $wpdb;
		$sSql = '';
		foreach($aIdList as $sId)
		{
			$sSql = 'DELETE FROM `' . $this->__sRealDbName . '` WHERE `' . sfs_clEnumDbCols::sIdRow . '` = ' . $sId . ';';
			$wpdb->query($sSql);
		}
	}

	/**
	 * fonction permettant de mettre a jour un enregistrement de la liste des formulaire du plugin (simaxFormSubmiter)
	 *
	 * @param string $sIdEnreg l'id de l'enregistrement sql a mettre a jour
	 * @param array $aColsDesc la description des colone a mettre a jour identifier par leur nom sql (sfs_clEnumDbCols)
	 */
	public function update_enreg($sIdEnreg, $aColsDesc = array())
	{
		global $wpdb;

		//on ne fait pas de maj si aucune colonne ne doit etre maj
		if(!empty($aColsDesc))
		{
			//on recupere les colonne existante grace a une classe de reflexion
			$oReflection = new ReflectionClass('sfs_clEnumDbCols');
	 		$aExistingCols = $oReflection->getConstants();
			//on enleve la colonne id
			unset($aExistingCols['sIdRow']);

			$sSql = 'UPDATE `' . $this->__sRealDbName . '` SET ';

			$bFirstElem = true;
			foreach($aExistingCols as $sKey => $sVal)
			{
				$sNewVal = '';

				if(isset($aColsDesc[$sVal]));
				{
					$sNewVal = $aColsDesc[$sVal];
				}

				if(!$bFirstElem) {
                    $sSql .= ',';
                }

				$sSql .= '`' . $sVal . '` = \'' . $sNewVal . '\' ';
				$bFirstElem = false;
			}

			$sSql .= 'WHERE `' . sfs_clEnumDbCols::sIdRow . '` =' . $sIdEnreg . ';';

			return $wpdb->query($sSql) !== false;
		}
	}

	/************************************************************************************************************/
	/*********** Fonctions sql consultation/liste ***************************************************************/

	/**
	 * fonction permettant de recuperer la liste des enregistrement de la base pour le plugin (simaxFormSubmiter)
	 *
	 * @return array le tableau des enregistrements.
	 */
	public function get_enreg_list()
	{
		global $wpdb;
		$sSql = 'SELECT * FROM `'. $this->__sRealDbName .'` WHERE `' . sfs_clEnumDbCols::sIdRow . '` >= 0 ORDER BY `' . sfs_clEnumDbCols::sIdRow . '` ASC';

		$aEnregs = $wpdb->get_results($sSql);

		$aFinalReturn = array();

		//on transforme les differente stdClass en tableau afin d'y acceder plus simplemetn
		if(is_array($aEnregs))
		{
			foreach($aEnregs as $oStdInfos)
			{
				$aFinalReturn[] =  get_object_vars($oStdInfos);
			}
		}

		return $aFinalReturn;
	}

	/**
	 * fonction permettant de recuperer la description d'un enregistrement de description du formulaire du plugin (simaxFormSubmiter)
	 *
	 * @param string $sEnregId
	 */
	public function get_enreg_desc($sEnregId)
	{
		global $wpdb;
		$sSql = 'SELECT * FROM `' . $this->__sRealDbName . '` WHERE `' . sfs_clEnumDbCols::sIdRow . '` = \'' . $sEnregId . '\';';

		$oStdClassEnregDesc = $wpdb->get_row($sSql);

		//on retourne un tableau et non une stdClass
		return get_object_vars($oStdClassEnregDesc);
	}

	/**
	 * fonction permettant de recuperer la description d'un formulaire simaxFormSubmiter
	 *
	 * @param stirng $sEnregId
	 */
	public function form_desc($sEnregId)
	{
		global $wpdb;
		$sSql = 'SELECT `' . sfs_clEnumDbCols::sFormDesc . '` FROM `' . $this->__sRealDbName . '` WHERE `' . sfs_clEnumDbCols::sIdRow . '` = \'' . $sEnregId . '\';';

		$aResp =  $wpdb->get_col($sSql);

		if(!is_array($aResp) || is_null($aResp[0])) {
            return '';
        }

		return $aResp[0];
	}

	/************************************************************************************************************/
	/*********** diverse fonction outils pour bdd ***************************************************************/
	/**
	 * fonction permettant de recuperer la chaine de "collation" mysql (CHARACTER SET et COLLATE)
	 *
	 * @return string
	 */
	function get_charset_collation()
	{
		//si on a pas encore generer la charset collation, on la genere
		if(is_null($this->__sCharsetCollation))
		{
			global $wpdb;

			$this->__sCharsetCollation = "";

			//establish the current charset / collation
			if (!empty($wpdb->charset)) {
                $this->__sCharsetCollation = "CHARACTER SET " . $wpdb->charset;
            }
			if (!empty($wpdb->collate)) {
                $this->__sCharsetCollation .= " COLLATE " . $wpdb->collate;
            }
		}

		//on retourne la charset collation
		return $this->__sCharsetCollation;
	}
}