<?php
/**
 * classe permettant la gestion des envoie de formulaire simaxFormSubmiter afin de les enregistrer dans simax.
 */

use NOUT\Soap\PackageBase\AbstractSoapClientBase;
class sfs_clFormSubmiter
{
    public const APIUUID = "6c41b770-92e7-4084-861a-3796a8e9dea0";
    public const OPT_TRACE = 'traces';


    private $__bTraces = false;
    private $__aOptions = [];


    private $__sError = '';
    private $__sErrorType = '';//('fatal'|'communication'|classic)
    public $aErrorTypeEnum = array('fatale' => 'fatale', 'communication' => 'de communication', 'classic' => 'classique');

    /**
     * constructeur
     *
     * @param string $sServiceEndPoint url du service au format (protocol :// url : port)(en cas d'absence de port le port 80 sera forc�)
     * @param string $sLogin le login de l'utilisateur simax
     * @param string $sEncodedPass le pass de l'utilisateur simax encoder (base_64 + md5 ou 'AAAAAAAAAAAAAAAAAAAAAA==' si mdp vide)
     * @param string $sApiUuId l'eventuel identificateur d'application.
     */
    public function __construct(array $aOptions)
    {
        $this->__bTraces = boolval($aOptions[self::OPT_TRACE] ?? false);
        $this->__aOptions = array_filter($aOptions, function($key) {
            return in_array($key,[
                    \NOUT\NOUTClient::OPT_PORT,
                    \NOUT\NOUTClient::OPT_APIUUID,
                    \NOUT\NOUTClient::OPT_SECRET,
                    \NOUT\NOUTClient::OPT_TOKEN,
                    \NOUT\NOUTClient::OPT_URL,
                    \NOUT\NOUTClient::OPT_HOST,
                ]);
        }, ARRAY_FILTER_USE_KEY);
    }

    /**
     * fonction permettant de creer l'enregistrement voulu dans simax grace a une communication avec le service simaxOnline
     * En cas d'erreur, et avant de retrouner un erreur à l'utilisateur, un essaie d'envoie des information par mail peu etre fait.
     *
     * @param string $sFormId identifiant du formulaire de l'enreg a creer
     * @param array description des valeur des colonnes de l'enreg a creer ('id_"l'id qui nous interesse"' => '"valeur qui nous interesse")
     * @param string $sRecupMail (optionnel) permet l'envoie eventuel des information par mail si l'enreg n'a pus etre creer
     * @return boolean true en cas de réussite (meme si juste envoie form par mail) false en cas d'echec
     */
    public function simax_send_info($sFormId, $aFormDesc = array(), $sRecupMail = '')
    {
        //on fait la liste des colonne a mettre a jour (uniquement les colonne avec id de type 'id_***');
        $aSelectedCols = array();
        if(is_array($aFormDesc))
        {
            foreach($aFormDesc as $sKey => $sVal)
            {
                if(strpos($sKey, 'id_') === 0) {
                    $aSelectedCols[$sKey] = $sVal;
                }
            }
        }

        //on tente d'executer la creation via le webService simaxOnline
        $bOk = $this->create_service_enreg($sFormId, $aFormDesc);

        if($bOk)
        {
            //reussite de l'action
            return true;
        }
        elseif($sRecupMail != '')
        {
            $sComplement = 'Ce message vous est envoyé car une erreur' . $this->aErrorTypeEnum[  $this->__sErrorType  ];
            $sComplement .= ' est survenu lors de la création de l\'enregistrement simax : ' . "\r\n" . $this->__sError;

            //on tente l'envoie des informations par mail.
            $bOk = $this->send_info_by_mail($sFormId, $sRecupMail, $aFormDesc, $sComplement);
            if($bOk)
            {
                //l'envoie de mail a reussis, on considere donc l'action comme ayant réussis.
                return true;
            }

        }

        return false;
    }

    /**
     * fonction permettant d'essayer de creer l'enregistrement simax via simaxOnline
     *
     * @param string $sFormId l'identifiant du formulaire pour lequel on souhaite creer un enregistrement.
     * @param array $aFormDesc la description des colonne de l'enreg a creer (id de la colonne => valeur)
     */

    private function create_service_enreg($sFormId, $aFormDesc = array())
    {
        $oCommunicator = new \NOUT\ManageData($this->__aOptions);
        $debugTrace = new \NOUT\DebugTrace($this->__bTraces);
        if ($this->__bTraces === true) {
            $oCommunicator->setDebugTrace($debugTrace);
            $debugTrace->startTrace();
        }

        try
        {

            if (!$oCommunicator->bConnecte()) {
                throw new \Exception("Échec de la connexion via bConnecte.");
            }

            $oCommunicator->manageData('create', $sFormId, null, $aFormDesc);
            $oCommunicator->bDisconnect();
            return true;
        }
        catch (Exception $oError)
        {
            $this->__sError = $oError->getMessage();
            $this->__sErrorType = $this->aErrorTypeEnum['fatale'];
            $oCommunicator->bDisconnect();
            return false;
        }
    }

    /**
     * fonction permettant d'envoyer les info recolter dans le formulaire simaxFormSubmitter par mail suite a une erreur du service.
     *
     * @param string $sFormId l'identifiant du formulaire dont l'on envoie les infos
     * @param string $sMail le mail auquel on envoie les info
     * @param array $aFormDesc la description des colonnes a envoyer
     * @param string $sAddInfo info complementaire passé dans le mail(optionnel)
     */
    private function send_info_by_mail($sFormId , $sMail , $aFormDesc = array(), $sAddInfo = '')
    {
        $sSubject = 'Envoie information simax formulaire ' . $sFormId;

        $sMessage = 'Bonjour, ' . "\n\n" . 'Ce message est envoyé depuis la page : http://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];

        if($sAddInfo)
        {
            $sMessage .= "\n\n" . $sAddInfo;
        }

        $sMessage .= "\n\n";
        $sMessage .= '----------Informations sur le formulaire : ------------------' . "\n\n";
        $sMessage .= 'Id du formulaire : ' . $sFormId . "\n\n";

        //parcour de toutes les colonnes
        if(is_array($aFormDesc))
        {
            foreach($aFormDesc as $sKey => $sVal)
            {
                if($sKey != 'sfs-form-ident') {
                    $sMessage .= 'Colonne ' . $sKey . ' : ' . $sVal . ',' . "\n";
                }
            }
        }

        $sHeaders = 'From: ' . $sMail . "\n" .
        'Reply-To: ' . $sMail . "\r\n" .
        'X-Mailer: PHP/' . phpversion() . "\n" .
        'MIME-Version: 1.0' . "\n" . 'Content-type: text/plain; charset=UTF-8;' . "\n";

        $bSend = false;
        try
        {
			$bSend = mail($sMail,  '=?UTF-8?B?'.base64_encode($sSubject).'?=', $sMessage, $sHeaders);
			return $bSend;
            //log(true);
        }
        catch(Exception $oError)
        {
            return false;
        }
    }


    //---------gestion des erreurs-------------------------------------------
    /**
     * fonction permettant de recuperer un eventuel message d'erreur.
     *
     * @return string le message d'erreur a retourner.
     */
    public function get_error_message()
    {
        return $this->__sError;
    }

    /***
     * Fonction permettant de recuperer l'eventuel type de l'erreur :
     *
     * @return string le type de l'erreur
     */
     public function get_error_type()
     {
        return $this->aErrorTypeEnum[ $this->__sErrorType  ];
     }
}
