<?php
/**
 * Génère la chaîne par défaut pour le message de réussite d'envoi d'informations.
 *
 * @return string Le message de réussite par défaut.
 */
function generate_default_send_success()
{
    return 'Vos informations nous ont bien été envoyées, nous vous contacterons sous peu.';
}

/**
 * Génère la chaîne par défaut pour le message d'échec d'envoi d'informations.
 *
 * @return string Le message d'erreur par défaut.
 */
function generate_default_send_error()
{
    return 'Une erreur a été rencontrée lors de l\'envoi de vos informations. <br /> Vous pouvez réessayer dans quelques instants ou nous contacter directement.';
}

/**
 * Génère une chaîne de message d'erreur fatale lors de l'initialisation d'un plugin.
 *
 * @param string $sAddInfo Chaîne d'informations supplémentaires sur l'erreur.
 * @return string Le message d'erreur fatale généré.
 */
function form_generation_fatal_error($sAddInfo = '')
{
    $sToReturn = '<div class="sfs_fatalError">Une erreur fatale a été rencontrée lors de l\'initialisation du plugin';

    if (!empty($sAddInfo)) {
        $sToReturn .= ' : ' . esc_html($sAddInfo);
    }

    $sToReturn .= '</div>';

    return $sToReturn;
}

/**
 * Génère la chaîne d'affichage de réussite de l'envoi d'un formulaire.
 *
 * @param string $sOverideMsg Le message de réussite personnalisé.
 * @return string Le message de réussite généré.
 */
function form_send_success($sOverideMsg = '')
{
    if (empty($sOverideMsg)) {
        $oOptionGest = new sfs_clSettingsGest();
        $sOverideMsg = stripslashes($oOptionGest->get_option_value(sfs_clEnumOption::sSuccessMessage));
    }
    return '<div class="sfs_formSendSuccess">' . esc_html($sOverideMsg) . '</div>';
}

/**
 * Génère la chaîne d'affichage des erreurs lors de l'envoi du formulaire.
 *
 * @param string $sOverideMsg Le message d'erreur personnalisé.
 * @param string $sErrorComplement Un complément d'information sur l'erreur.
 * @return string Le message d'erreur généré.
 */
function form_send_error($sOverideMsg = '', $sErrorComplement = '')
{
    if (empty($sOverideMsg)) {
        $oOptionGest = new sfs_clSettingsGest();
        $sOverideMsg = stripslashes($oOptionGest->get_option_value(sfs_clEnumOption::sErrorMessage));
    }

    return '<div class="sfs_formSendError">' . esc_html($sOverideMsg) . '<br /><br />' . esc_html($sErrorComplement) . '</div>';
}

/**
 * Génère le formulaire final pour l'affichage de SimaxFormSubmitter.
 *
 * @param int $nIdForm L'identifiant du formulaire SimaxFormSubmitter.
 * @param string $sFormContent Le contenu du formulaire (fourni en paramètre du shortcode).
 * @return string Le formulaire généré.
 */
function final_form_generation($nIdForm, $sFormContent = '')
{
    $sToReturn = '<form method="post">' . "\r\n";
    $sToReturn .= '<input type="hidden" name="sfs-form-ident" id="sfs-form-ident" value="' . esc_attr($nIdForm) . '" />' . "\r\n";
    $sToReturn .= $sFormContent . "\r\n";
    $sToReturn .= '</form>';

    return $sToReturn;
}
?>