<?php
/*
Plugin Name: SIMAXFormSubmiter
Plugin URI: https://simax.fr/SIMAX-wordpress-FormSubmiter/
Description: Plugin permettant de créer des enregistrements SIMAX sur validation de formulaire.
Author: simax
Version: 2449.01
Author URI: https://www.simax.fr
*/

/*******************************************************************/
/****************** Sécurité : Empêcher l'accès direct **************/
if (!defined('ABSPATH')) {
    exit('Access Denied');
}

/*******************************************************************/
/****************** Inclusions nécessaires *************************/
require_once plugin_dir_path(__FILE__) . 'display.php';
require_once plugin_dir_path(__FILE__) . 'clFormSubmiter.php';
require_once plugin_dir_path(__FILE__) . 'settings.php';
require_once plugin_dir_path(__FILE__) . 'clDbGest.php';
require_once plugin_dir_path(__FILE__) . '/vendor/autoload.php';

/*******************************************************************/
/****************** Gestion de la base de données ******************/
global $wpdb, $o_sfs_dbGest;
$o_sfs_dbGest = new sfs_clDbGest();

/*******************************************************************/
/****************** Installation du plugin *************************/
register_activation_hook(__FILE__, 'sfs_install');
function sfs_install()
{
    // Préparation des valeurs d'option par défaut
    $defaultOptions = [
        sfs_clEnumOption::sErrorMessage   => generate_default_send_error(),
        sfs_clEnumOption::sSuccessMessage => generate_default_send_success(),
    ];

    // Initialisation des options
    $settingsGest = new sfs_clSettingsGest();
    $settingsGest->init_plugin_opts($defaultOptions);

    // Initialisation de la base de données
    global $o_sfs_dbGest;
    $o_sfs_dbGest->install_bdd();
}

/*******************************************************************/
/****************** Désinstallation du plugin **********************/
register_deactivation_hook(__FILE__, 'sfs_uninstall');
function sfs_uninstall()
{
    // Suppression des options du plugin
    $settingsGest = new sfs_clSettingsGest();
    $settingsGest->remove_plugin_opt();

    global $o_sfs_dbGest;
    $o_sfs_dbGest->uninstall_bdd();
}

/*******************************************************************/
/****************** Initialisation du plugin ***********************/
add_action('init', 'sfs_init');
function sfs_init()
{
    wp_register_style('simaxFormManager-css', plugins_url('/style/css/style.css', __FILE__));
    wp_enqueue_style('simaxFormManager-css');
}

/*******************************************************************/
/****************** Menu d'administration **************************/
add_action('admin_menu', 'sfs_admin_actions');
function sfs_admin_actions()
{
    // Option dans la liste des menus
    add_menu_page(
        'SimaxFormS',
        'SimaxFormS',
        'manage_options',
        'sfs-optionPage-id',
        'sfs_listeForm',
        plugins_url('/style/formmanage.png', __FILE__)
    );

    add_submenu_page(
        'sfs-optionPage-id',
        'Réglages',
        'Réglages',
        'manage_options',
        'sfs-mainOptionPage-id',
        'sfs_mainOptionPage'
    );

    add_submenu_page(
        '',
        'Éditer',
        'Éditer',
        'manage_options',
        'sfs-editFormPage-id',
        'sfs_showEditPage'
    );
}

function sfs_mainOptionPage()
{
    include plugin_dir_path(__FILE__) . 'pages/editOptions.php';
}

function sfs_listeForm()
{
    include plugin_dir_path(__FILE__) . 'pages/main.php';
}

function sfs_showEditPage()
{
    include plugin_dir_path(__FILE__) . 'pages/editEnreg.php';
}

/*******************************************************************/
/****************** Initialisation des shortcodes ******************/
add_shortcode('sfs-form-identification', 'sfs_form_identification_handler');
function sfs_form_identification_handler($atts, $content = null)
{
    $atts = shortcode_atts(['id' => ''], $atts);
    $form_id = $atts['id'];

    if (empty($form_id)) {
        return form_generation_fatal_error('Absence d\'identifiant de formulaire');
    }

    $settingsGest = new sfs_clSettingsGest();
    $aOptCnx = [];
    if ($settingsGest->get_option_value(sfs_clEnumOption::sTypeAdresse) == 'proxy'){
        $url = $settingsGest->get_option_value(sfs_clEnumOption::sUrl);
        if (empty($url)){
            return form_generation_fatal_error('Paramètres de service non définis correctement dans les options.');
        }
        $aOptCnx[\NOUT\NOUTClient::OPT_URL]=$url;
    }
    else {
        $service_host = $settingsGest->get_option_value(sfs_clEnumOption::sHost);
        $service_port = $settingsGest->get_option_value(sfs_clEnumOption::sPort);
        if (empty($service_host) || empty($service_port) || (intval($service_port)==0)) {
            return form_generation_fatal_error('Paramètres de service non définis correctement dans les options.');
        }
        $aOptCnx[\NOUT\NOUTClient::OPT_HOST]=$service_host;
        $aOptCnx[\NOUT\NOUTClient::OPT_PORT]=$service_port;
    }

    $service_token = $settingsGest->get_option_value(sfs_clEnumOption::sToken);

    if (empty($service_token) || !is_string($service_token)) {
        return form_generation_fatal_error('Paramètres de service non définis correctement dans les options.');
    }

    global $o_sfs_dbGest;
    $display_form = true;
    $return_content = '';

    if (isset($_POST['sfs-form-ident'])) {
        $display_form = false;

        $enreg_info = $o_sfs_dbGest->get_enreg_desc($form_id);
        $recup_mail = $enreg_info[sfs_clEnumDbCols::sRecupMail] ?: $settingsGest->get_option_value(sfs_clEnumOption::sEmailRecupError);

        $aOptions=[
            \NOUT\NOUTClient::OPT_TOKEN => $service_token,
            \NOUT\NOUTClient::OPT_APIUUID => $settingsGest->get_option_value(sfs_clEnumOption::sUserApiuuId),
            \NOUT\NOUTClient::OPT_SECRET => $settingsGest->get_option_value(sfs_clEnumOption::sSecretPhrase),
            sfs_clFormSubmiter::OPT_TRACE => $settingsGest->get_option_value(sfs_clEnumOption::bTraces),
        ];
        $form_validator = new sfs_clFormSubmiter($aOptions+$aOptCnx);
        $form_sent = $form_validator->simax_send_info($enreg_info[sfs_clEnumDbCols::sIdSimaxForm], $_POST, $recup_mail);

        if ($form_sent) {
            $override_msg = $enreg_info[sfs_clEnumDbCols::sSuccess] ?? '';
            $return_content .= form_send_success($override_msg);
        } else {
            $display_form = true;
            $override_msg = $enreg_info[sfs_clEnumDbCols::sError] ?? '';
            $return_content .= form_send_error($override_msg, $form_validator->get_error_type() . ' ' . $form_validator->get_error_message());
        }
    }

    if ($display_form) {
        $form_content = $o_sfs_dbGest->form_desc($form_id);
        $return_content .= final_form_generation($form_id, $form_content);
    }

    return $return_content;
}
